# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: testpb/bank.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.orm.v1 import orm_pb2 as cosmos_dot_orm_dot_v1_dot_orm__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11testpb/bank.proto\x12\x06testpb\x1a\x17\x63osmos/orm/v1/orm.proto\"_\n\x07\x42\x61lance\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x04:$\xf2\x9e\xd3\x8e\x03\x1e\n\x0f\n\raddress,denom\x12\t\n\x05\x64\x65nom\x10\x01\x18\x01\":\n\x06Supply\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x04:\x11\xf2\x9e\xd3\x8e\x03\x0b\n\x07\n\x05\x64\x65nom\x18\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'testpb.bank_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BALANCE._options = None
  _BALANCE._serialized_options = b'\362\236\323\216\003\036\n\017\n\raddress,denom\022\t\n\005denom\020\001\030\001'
  _SUPPLY._options = None
  _SUPPLY._serialized_options = b'\362\236\323\216\003\013\n\007\n\005denom\030\002'
  _globals['_BALANCE']._serialized_start=54
  _globals['_BALANCE']._serialized_end=149
  _globals['_SUPPLY']._serialized_start=151
  _globals['_SUPPLY']._serialized_end=209
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/v1beta1/coin.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63osmos/base/v1beta1/coin.proto\x12\x13\x63osmos.base.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"K\n\x04\x43oin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12.\n\x06\x61mount\x18\x02 \x01(\tB\x1e\xc8\xde\x1f\x00\xda\xde\x1f\x03Int\xd2\xb4-\ncosmos.Int\xa8\xe7\xb0*\x01:\x04\xe8\xa0\x1f\x01\"I\n\x07\x44\x65\x63\x43oin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12)\n\x06\x61mount\x18\x02 \x01(\tB\x19\xc8\xde\x1f\x00\xda\xde\x1f\x03\x44\x65\x63\xd2\xb4-\ncosmos.Dec:\x04\xe8\xa0\x1f\x01\"2\n\x08IntProto\x12&\n\x03int\x18\x01 \x01(\tB\x19\xc8\xde\x1f\x00\xda\xde\x1f\x03Int\xd2\xb4-\ncosmos.Int\"2\n\x08\x44\x65\x63Proto\x12&\n\x03\x64\x65\x63\x18\x01 \x01(\tB\x19\xc8\xde\x1f\x00\xda\xde\x1f\x03\x44\x65\x63\xd2\xb4-\ncosmos.DecB,Z\"github.com/cosmos/cosmos-sdk/types\xd8\xe1\x1e\x00\x80\xe2\x1e\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.v1beta1.coin_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\"github.com/cosmos/cosmos-sdk/types\330\341\036\000\200\342\036\000'
  _COIN.fields_by_name['amount']._options = None
  _COIN.fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\003Int\322\264-\ncosmos.Int\250\347\260*\001'
  _COIN._options = None
  _COIN._serialized_options = b'\350\240\037\001'
  _DECCOIN.fields_by_name['amount']._options = None
  _DECCOIN.fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\003Dec\322\264-\ncosmos.Dec'
  _DECCOIN._options = None
  _DECCOIN._serialized_options = b'\350\240\037\001'
  _INTPROTO.fields_by_name['int']._options = None
  _INTPROTO.fields_by_name['int']._serialized_options = b'\310\336\037\000\332\336\037\003Int\322\264-\ncosmos.Int'
  _DECPROTO.fields_by_name['dec']._options = None
  _DECPROTO.fields_by_name['dec']._serialized_options = b'\310\336\037\000\332\336\037\003Dec\322\264-\ncosmos.Dec'
  _globals['_COIN']._serialized_start=123
  _globals['_COIN']._serialized_end=198
  _globals['_DECCOIN']._serialized_start=200
  _globals['_DECCOIN']._serialized_end=273
  _globals['_INTPROTO']._serialized_start=275
  _globals['_INTPROTO']._serialized_end=325
  _globals['_DECPROTO']._serialized_start=327
  _globals['_DECPROTO']._serialized_end=377
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from exchange import injective_derivative_exchange_rpc_pb2 as exchange_dot_injective__derivative__exchange__rpc__pb2


class InjectiveDerivativeExchangeRPCStub(object):
    """InjectiveDerivativeExchangeRPC defines gRPC API of Derivative Markets
    provider.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Markets = channel.unary_unary(
                '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/Markets',
                request_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.MarketsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.MarketsResponse.FromString,
                )
        self.Market = channel.unary_unary(
                '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/Market',
                request_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.MarketRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.MarketResponse.FromString,
                )
        self.StreamMarket = channel.unary_stream(
                '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/StreamMarket',
                request_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamMarketRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamMarketResponse.FromString,
                )
        self.BinaryOptionsMarkets = channel.unary_unary(
                '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/BinaryOptionsMarkets',
                request_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.BinaryOptionsMarketsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.BinaryOptionsMarketsResponse.FromString,
                )
        self.BinaryOptionsMarket = channel.unary_unary(
                '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/BinaryOptionsMarket',
                request_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.BinaryOptionsMarketRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.BinaryOptionsMarketResponse.FromString,
                )
        self.OrderbookV2 = channel.unary_unary(
                '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/OrderbookV2',
                request_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.OrderbookV2Request.SerializeToString,
                response_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.OrderbookV2Response.FromString,
                )
        self.OrderbooksV2 = channel.unary_unary(
                '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/OrderbooksV2',
                request_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.OrderbooksV2Request.SerializeToString,
                response_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.OrderbooksV2Response.FromString,
                )
        self.StreamOrderbookV2 = channel.unary_stream(
                '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/StreamOrderbookV2',
                request_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamOrderbookV2Request.SerializeToString,
                response_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamOrderbookV2Response.FromString,
                )
        self.StreamOrderbookUpdate = channel.unary_stream(
                '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/StreamOrderbookUpdate',
                request_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamOrderbookUpdateRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamOrderbookUpdateResponse.FromString,
                )
        self.Orders = channel.unary_unary(
                '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/Orders',
                request_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.OrdersRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.OrdersResponse.FromString,
                )
        self.Positions = channel.unary_unary(
                '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/Positions',
                request_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.PositionsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.PositionsResponse.FromString,
                )
        self.LiquidablePositions = channel.unary_unary(
                '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/LiquidablePositions',
                request_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.LiquidablePositionsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.LiquidablePositionsResponse.FromString,
                )
        self.FundingPayments = channel.unary_unary(
                '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/FundingPayments',
                request_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.FundingPaymentsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.FundingPaymentsResponse.FromString,
                )
        self.FundingRates = channel.unary_unary(
                '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/FundingRates',
                request_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.FundingRatesRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.FundingRatesResponse.FromString,
                )
        self.StreamPositions = channel.unary_stream(
                '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/StreamPositions',
                request_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamPositionsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamPositionsResponse.FromString,
                )
        self.StreamOrders = channel.unary_stream(
                '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/StreamOrders',
                request_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamOrdersRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamOrdersResponse.FromString,
                )
        self.Trades = channel.unary_unary(
                '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/Trades',
                request_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.TradesRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.TradesResponse.FromString,
                )
        self.StreamTrades = channel.unary_stream(
                '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/StreamTrades',
                request_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamTradesRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamTradesResponse.FromString,
                )
        self.SubaccountOrdersList = channel.unary_unary(
                '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/SubaccountOrdersList',
                request_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.SubaccountOrdersListRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.SubaccountOrdersListResponse.FromString,
                )
        self.SubaccountTradesList = channel.unary_unary(
                '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/SubaccountTradesList',
                request_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.SubaccountTradesListRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.SubaccountTradesListResponse.FromString,
                )
        self.OrdersHistory = channel.unary_unary(
                '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/OrdersHistory',
                request_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.OrdersHistoryRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.OrdersHistoryResponse.FromString,
                )
        self.StreamOrdersHistory = channel.unary_stream(
                '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/StreamOrdersHistory',
                request_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamOrdersHistoryRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamOrdersHistoryResponse.FromString,
                )


class InjectiveDerivativeExchangeRPCServicer(object):
    """InjectiveDerivativeExchangeRPC defines gRPC API of Derivative Markets
    provider.
    """

    def Markets(self, request, context):
        """Markets gets a list of Derivative Markets
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Market(self, request, context):
        """Market gets details of a single derivative market
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamMarket(self, request, context):
        """StreamMarket streams live updates of selected derivative markets
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BinaryOptionsMarkets(self, request, context):
        """BinaryOptionsMarkets gets a list of Binary Options Markets
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BinaryOptionsMarket(self, request, context):
        """BinaryOptionMarket gets details of a single binary options market
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OrderbookV2(self, request, context):
        """Orderbook gets the Orderbook of a Derivative Market
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OrderbooksV2(self, request, context):
        """Orderbooks gets the Orderbooks of requested derivative markets
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamOrderbookV2(self, request, context):
        """Stream live snapshot updates of selected derivative market orderbook
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamOrderbookUpdate(self, request, context):
        """Stream live level updates of selected derivative market orderbook
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Orders(self, request, context):
        """DerivativeLimitOrders gets the limit orders of a derivative Market.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Positions(self, request, context):
        """Positions gets the positions for a trader.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LiquidablePositions(self, request, context):
        """LiquidablePositions gets all the liquidable positions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FundingPayments(self, request, context):
        """FundingPayments gets the funding payments for a trader.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FundingRates(self, request, context):
        """FundingRates gets the historical funding rates for a market.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamPositions(self, request, context):
        """StreamPositions streams derivatives position updates.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamOrders(self, request, context):
        """StreamOrders streams updates to individual orders of a Derivative Market.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Trades(self, request, context):
        """Trades gets the trades of a Derivative Market.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamTrades(self, request, context):
        """StreamTrades streams newly executed trades from Derivative Market.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubaccountOrdersList(self, request, context):
        """SubaccountOrdersList lists orders posted from this subaccount.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubaccountTradesList(self, request, context):
        """SubaccountTradesList gets a list of derivatives trades executed by this
        subaccount.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OrdersHistory(self, request, context):
        """Lists history orders posted from a subaccount
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamOrdersHistory(self, request, context):
        """Stream updates to historical orders of a derivative Market
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InjectiveDerivativeExchangeRPCServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Markets': grpc.unary_unary_rpc_method_handler(
                    servicer.Markets,
                    request_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.MarketsRequest.FromString,
                    response_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.MarketsResponse.SerializeToString,
            ),
            'Market': grpc.unary_unary_rpc_method_handler(
                    servicer.Market,
                    request_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.MarketRequest.FromString,
                    response_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.MarketResponse.SerializeToString,
            ),
            'StreamMarket': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamMarket,
                    request_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamMarketRequest.FromString,
                    response_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamMarketResponse.SerializeToString,
            ),
            'BinaryOptionsMarkets': grpc.unary_unary_rpc_method_handler(
                    servicer.BinaryOptionsMarkets,
                    request_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.BinaryOptionsMarketsRequest.FromString,
                    response_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.BinaryOptionsMarketsResponse.SerializeToString,
            ),
            'BinaryOptionsMarket': grpc.unary_unary_rpc_method_handler(
                    servicer.BinaryOptionsMarket,
                    request_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.BinaryOptionsMarketRequest.FromString,
                    response_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.BinaryOptionsMarketResponse.SerializeToString,
            ),
            'OrderbookV2': grpc.unary_unary_rpc_method_handler(
                    servicer.OrderbookV2,
                    request_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.OrderbookV2Request.FromString,
                    response_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.OrderbookV2Response.SerializeToString,
            ),
            'OrderbooksV2': grpc.unary_unary_rpc_method_handler(
                    servicer.OrderbooksV2,
                    request_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.OrderbooksV2Request.FromString,
                    response_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.OrderbooksV2Response.SerializeToString,
            ),
            'StreamOrderbookV2': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamOrderbookV2,
                    request_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamOrderbookV2Request.FromString,
                    response_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamOrderbookV2Response.SerializeToString,
            ),
            'StreamOrderbookUpdate': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamOrderbookUpdate,
                    request_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamOrderbookUpdateRequest.FromString,
                    response_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamOrderbookUpdateResponse.SerializeToString,
            ),
            'Orders': grpc.unary_unary_rpc_method_handler(
                    servicer.Orders,
                    request_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.OrdersRequest.FromString,
                    response_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.OrdersResponse.SerializeToString,
            ),
            'Positions': grpc.unary_unary_rpc_method_handler(
                    servicer.Positions,
                    request_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.PositionsRequest.FromString,
                    response_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.PositionsResponse.SerializeToString,
            ),
            'LiquidablePositions': grpc.unary_unary_rpc_method_handler(
                    servicer.LiquidablePositions,
                    request_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.LiquidablePositionsRequest.FromString,
                    response_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.LiquidablePositionsResponse.SerializeToString,
            ),
            'FundingPayments': grpc.unary_unary_rpc_method_handler(
                    servicer.FundingPayments,
                    request_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.FundingPaymentsRequest.FromString,
                    response_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.FundingPaymentsResponse.SerializeToString,
            ),
            'FundingRates': grpc.unary_unary_rpc_method_handler(
                    servicer.FundingRates,
                    request_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.FundingRatesRequest.FromString,
                    response_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.FundingRatesResponse.SerializeToString,
            ),
            'StreamPositions': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamPositions,
                    request_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamPositionsRequest.FromString,
                    response_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamPositionsResponse.SerializeToString,
            ),
            'StreamOrders': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamOrders,
                    request_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamOrdersRequest.FromString,
                    response_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamOrdersResponse.SerializeToString,
            ),
            'Trades': grpc.unary_unary_rpc_method_handler(
                    servicer.Trades,
                    request_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.TradesRequest.FromString,
                    response_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.TradesResponse.SerializeToString,
            ),
            'StreamTrades': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamTrades,
                    request_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamTradesRequest.FromString,
                    response_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamTradesResponse.SerializeToString,
            ),
            'SubaccountOrdersList': grpc.unary_unary_rpc_method_handler(
                    servicer.SubaccountOrdersList,
                    request_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.SubaccountOrdersListRequest.FromString,
                    response_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.SubaccountOrdersListResponse.SerializeToString,
            ),
            'SubaccountTradesList': grpc.unary_unary_rpc_method_handler(
                    servicer.SubaccountTradesList,
                    request_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.SubaccountTradesListRequest.FromString,
                    response_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.SubaccountTradesListResponse.SerializeToString,
            ),
            'OrdersHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.OrdersHistory,
                    request_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.OrdersHistoryRequest.FromString,
                    response_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.OrdersHistoryResponse.SerializeToString,
            ),
            'StreamOrdersHistory': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamOrdersHistory,
                    request_deserializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamOrdersHistoryRequest.FromString,
                    response_serializer=exchange_dot_injective__derivative__exchange__rpc__pb2.StreamOrdersHistoryResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InjectiveDerivativeExchangeRPC(object):
    """InjectiveDerivativeExchangeRPC defines gRPC API of Derivative Markets
    provider.
    """

    @staticmethod
    def Markets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/Markets',
            exchange_dot_injective__derivative__exchange__rpc__pb2.MarketsRequest.SerializeToString,
            exchange_dot_injective__derivative__exchange__rpc__pb2.MarketsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Market(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/Market',
            exchange_dot_injective__derivative__exchange__rpc__pb2.MarketRequest.SerializeToString,
            exchange_dot_injective__derivative__exchange__rpc__pb2.MarketResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamMarket(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/StreamMarket',
            exchange_dot_injective__derivative__exchange__rpc__pb2.StreamMarketRequest.SerializeToString,
            exchange_dot_injective__derivative__exchange__rpc__pb2.StreamMarketResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BinaryOptionsMarkets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/BinaryOptionsMarkets',
            exchange_dot_injective__derivative__exchange__rpc__pb2.BinaryOptionsMarketsRequest.SerializeToString,
            exchange_dot_injective__derivative__exchange__rpc__pb2.BinaryOptionsMarketsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BinaryOptionsMarket(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/BinaryOptionsMarket',
            exchange_dot_injective__derivative__exchange__rpc__pb2.BinaryOptionsMarketRequest.SerializeToString,
            exchange_dot_injective__derivative__exchange__rpc__pb2.BinaryOptionsMarketResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OrderbookV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/OrderbookV2',
            exchange_dot_injective__derivative__exchange__rpc__pb2.OrderbookV2Request.SerializeToString,
            exchange_dot_injective__derivative__exchange__rpc__pb2.OrderbookV2Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OrderbooksV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/OrderbooksV2',
            exchange_dot_injective__derivative__exchange__rpc__pb2.OrderbooksV2Request.SerializeToString,
            exchange_dot_injective__derivative__exchange__rpc__pb2.OrderbooksV2Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamOrderbookV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/StreamOrderbookV2',
            exchange_dot_injective__derivative__exchange__rpc__pb2.StreamOrderbookV2Request.SerializeToString,
            exchange_dot_injective__derivative__exchange__rpc__pb2.StreamOrderbookV2Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamOrderbookUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/StreamOrderbookUpdate',
            exchange_dot_injective__derivative__exchange__rpc__pb2.StreamOrderbookUpdateRequest.SerializeToString,
            exchange_dot_injective__derivative__exchange__rpc__pb2.StreamOrderbookUpdateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Orders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/Orders',
            exchange_dot_injective__derivative__exchange__rpc__pb2.OrdersRequest.SerializeToString,
            exchange_dot_injective__derivative__exchange__rpc__pb2.OrdersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Positions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/Positions',
            exchange_dot_injective__derivative__exchange__rpc__pb2.PositionsRequest.SerializeToString,
            exchange_dot_injective__derivative__exchange__rpc__pb2.PositionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LiquidablePositions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/LiquidablePositions',
            exchange_dot_injective__derivative__exchange__rpc__pb2.LiquidablePositionsRequest.SerializeToString,
            exchange_dot_injective__derivative__exchange__rpc__pb2.LiquidablePositionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FundingPayments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/FundingPayments',
            exchange_dot_injective__derivative__exchange__rpc__pb2.FundingPaymentsRequest.SerializeToString,
            exchange_dot_injective__derivative__exchange__rpc__pb2.FundingPaymentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FundingRates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/FundingRates',
            exchange_dot_injective__derivative__exchange__rpc__pb2.FundingRatesRequest.SerializeToString,
            exchange_dot_injective__derivative__exchange__rpc__pb2.FundingRatesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamPositions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/StreamPositions',
            exchange_dot_injective__derivative__exchange__rpc__pb2.StreamPositionsRequest.SerializeToString,
            exchange_dot_injective__derivative__exchange__rpc__pb2.StreamPositionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamOrders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/StreamOrders',
            exchange_dot_injective__derivative__exchange__rpc__pb2.StreamOrdersRequest.SerializeToString,
            exchange_dot_injective__derivative__exchange__rpc__pb2.StreamOrdersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Trades(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/Trades',
            exchange_dot_injective__derivative__exchange__rpc__pb2.TradesRequest.SerializeToString,
            exchange_dot_injective__derivative__exchange__rpc__pb2.TradesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamTrades(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/StreamTrades',
            exchange_dot_injective__derivative__exchange__rpc__pb2.StreamTradesRequest.SerializeToString,
            exchange_dot_injective__derivative__exchange__rpc__pb2.StreamTradesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubaccountOrdersList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/SubaccountOrdersList',
            exchange_dot_injective__derivative__exchange__rpc__pb2.SubaccountOrdersListRequest.SerializeToString,
            exchange_dot_injective__derivative__exchange__rpc__pb2.SubaccountOrdersListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubaccountTradesList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/SubaccountTradesList',
            exchange_dot_injective__derivative__exchange__rpc__pb2.SubaccountTradesListRequest.SerializeToString,
            exchange_dot_injective__derivative__exchange__rpc__pb2.SubaccountTradesListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def OrdersHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/OrdersHistory',
            exchange_dot_injective__derivative__exchange__rpc__pb2.OrdersHistoryRequest.SerializeToString,
            exchange_dot_injective__derivative__exchange__rpc__pb2.OrdersHistoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamOrdersHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/injective_derivative_exchange_rpc.InjectiveDerivativeExchangeRPC/StreamOrdersHistory',
            exchange_dot_injective__derivative__exchange__rpc__pb2.StreamOrdersHistoryRequest.SerializeToString,
            exchange_dot_injective__derivative__exchange__rpc__pb2.StreamOrdersHistoryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



class PyInjectiveError(Exception):
    pass


class ValueTooLargeError(PyInjectiveError):
    pass


class EmptyMsgError(PyInjectiveError):
    pass


class NotFoundError(PyInjectiveError):
    pass


class UndefinedError(PyInjectiveError):
    pass


class DecodeError(PyInjectiveError):
    pass


class ConvertError(PyInjectiveError):
    pass


class SchemaError(PyInjectiveError):
    pass



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/wasmx/v1/proposal.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from cosmwasm.wasm.v1 import proposal_pb2 as cosmwasm_dot_wasm_dot_v1_dot_proposal__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!injective/wasmx/v1/proposal.proto\x12\x12injective.wasmx.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1f\x63osmwasm/wasm/v1/proposal.proto\x1a\x14gogoproto/gogo.proto\"\xcf\x01\n#ContractRegistrationRequestProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\\\n\x1d\x63ontract_registration_request\x18\x03 \x01(\x0b\x32/.injective.wasmx.v1.ContractRegistrationRequestB\x04\xc8\xde\x1f\x00:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\xd5\x01\n(BatchContractRegistrationRequestProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12]\n\x1e\x63ontract_registration_requests\x18\x03 \x03(\x0b\x32/.injective.wasmx.v1.ContractRegistrationRequestB\x04\xc8\xde\x1f\x00:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\x84\x01\n#BatchContractDeregistrationProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tcontracts\x18\x03 \x03(\t:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\xb0\x02\n\x1b\x43ontractRegistrationRequest\x12\x18\n\x10\x63ontract_address\x18\x01 \x01(\t\x12\x11\n\tgas_limit\x18\x02 \x01(\x04\x12\x11\n\tgas_price\x18\x03 \x01(\x04\x12\x1b\n\x13should_pin_contract\x18\x04 \x01(\x08\x12\x1c\n\x14is_migration_allowed\x18\x05 \x01(\x08\x12\x0f\n\x07\x63ode_id\x18\x06 \x01(\x04\x12\x15\n\radmin_address\x18\x07 \x01(\t\x12\x17\n\x0fgranter_address\x18\x08 \x01(\t\x12\x35\n\x0c\x66unding_mode\x18\t \x01(\x0e\x32\x1f.injective.wasmx.v1.FundingMode:\x1e\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\"\xa2\x01\n\x16\x42\x61tchStoreCodeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12<\n\tproposals\x18\x03 \x03(\x0b\x32#.cosmwasm.wasm.v1.StoreCodeProposalB\x04\xc8\xde\x1f\x00:&\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content*G\n\x0b\x46undingMode\x12\x0f\n\x0bUnspecified\x10\x00\x12\x0e\n\nSelfFunded\x10\x01\x12\r\n\tGrantOnly\x10\x02\x12\x08\n\x04\x44ual\x10\x03\x42MZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.wasmx.v1.proposal_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types'
  _CONTRACTREGISTRATIONREQUESTPROPOSAL.fields_by_name['contract_registration_request']._options = None
  _CONTRACTREGISTRATIONREQUESTPROPOSAL.fields_by_name['contract_registration_request']._serialized_options = b'\310\336\037\000'
  _CONTRACTREGISTRATIONREQUESTPROPOSAL._options = None
  _CONTRACTREGISTRATIONREQUESTPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _BATCHCONTRACTREGISTRATIONREQUESTPROPOSAL.fields_by_name['contract_registration_requests']._options = None
  _BATCHCONTRACTREGISTRATIONREQUESTPROPOSAL.fields_by_name['contract_registration_requests']._serialized_options = b'\310\336\037\000'
  _BATCHCONTRACTREGISTRATIONREQUESTPROPOSAL._options = None
  _BATCHCONTRACTREGISTRATIONREQUESTPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _BATCHCONTRACTDEREGISTRATIONPROPOSAL._options = None
  _BATCHCONTRACTDEREGISTRATIONPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _CONTRACTREGISTRATIONREQUEST._options = None
  _CONTRACTREGISTRATIONREQUEST._serialized_options = b'\312\264-\032cosmos.gov.v1beta1.Content'
  _BATCHSTORECODEPROPOSAL.fields_by_name['proposals']._options = None
  _BATCHSTORECODEPROPOSAL.fields_by_name['proposals']._serialized_options = b'\310\336\037\000'
  _BATCHSTORECODEPROPOSAL._options = None
  _BATCHSTORECODEPROPOSAL._serialized_options = b'\210\240\037\000\350\240\037\000\312\264-\032cosmos.gov.v1beta1.Content'
  _globals['_FUNDINGMODE']._serialized_start=1172
  _globals['_FUNDINGMODE']._serialized_end=1243
  _globals['_CONTRACTREGISTRATIONREQUESTPROPOSAL']._serialized_start=140
  _globals['_CONTRACTREGISTRATIONREQUESTPROPOSAL']._serialized_end=347
  _globals['_BATCHCONTRACTREGISTRATIONREQUESTPROPOSAL']._serialized_start=350
  _globals['_BATCHCONTRACTREGISTRATIONREQUESTPROPOSAL']._serialized_end=563
  _globals['_BATCHCONTRACTDEREGISTRATIONPROPOSAL']._serialized_start=566
  _globals['_BATCHCONTRACTDEREGISTRATIONPROPOSAL']._serialized_end=698
  _globals['_CONTRACTREGISTRATIONREQUEST']._serialized_start=701
  _globals['_CONTRACTREGISTRATIONREQUEST']._serialized_end=1005
  _globals['_BATCHSTORECODEPROPOSAL']._serialized_start=1008
  _globals['_BATCHSTORECODEPROPOSAL']._serialized_end=1170
# @@protoc_insertion_point(module_scope)



from pyinjective.constant import devnet_config, mainnet_config, testnet_config


class Denom:
    def __init__(
        self, description: str, base: int, quote: int, min_price_tick_size: float, min_quantity_tick_size: float
    ):
        self.description = description
        self.base = base
        self.quote = quote
        self.min_price_tick_size = min_price_tick_size
        self.min_quantity_tick_size = min_quantity_tick_size

    @classmethod
    def load_market(cls, network, market_id):
        if network == "devnet":
            config = devnet_config
        elif network == "testnet":
            config = testnet_config
        else:
            config = mainnet_config

        return cls(
            description=config[market_id]["description"],
            base=int(config[market_id]["base"]),
            quote=int(config[market_id]["quote"]),
            min_price_tick_size=float(config[market_id]["min_price_tick_size"]),
            min_quantity_tick_size=float(config[market_id]["min_quantity_tick_size"]),
        )

    @classmethod
    def load_peggy_denom(cls, network, symbol):
        if network == "devnet":
            config = devnet_config
        elif network == "local":
            config = devnet_config
        elif network == "testnet":
            config = testnet_config
        else:
            config = mainnet_config
        return config[symbol]["peggy_denom"], int(config[symbol]["decimals"])



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from injective.peggy.v1 import types_pb2 as injective_dot_peggy_dot_v1_dot_types__pb2
from injective.peggy.v1 import msgs_pb2 as injective_dot_peggy_dot_v1_dot_msgs__pb2
from injective.peggy.v1 import batch_pb2 as injective_dot_peggy_dot_v1_dot_batch__pb2
from injective.peggy.v1 import attestation_pb2 as injective_dot_peggy_dot_v1_dot_attestation__pb2
from injective.peggy.v1 import params_pb2 as injective_dot_peggy_dot_v1_dot_params__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n injective/peggy/v1/genesis.proto\x12\x12injective.peggy.v1\x1a\x14gogoproto/gogo.proto\x1a\x1einjective/peggy/v1/types.proto\x1a\x1dinjective/peggy/v1/msgs.proto\x1a\x1einjective/peggy/v1/batch.proto\x1a$injective/peggy/v1/attestation.proto\x1a\x1finjective/peggy/v1/params.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x80\x06\n\x0cGenesisState\x12*\n\x06params\x18\x01 \x01(\x0b\x32\x1a.injective.peggy.v1.Params\x12\x1b\n\x13last_observed_nonce\x18\x02 \x01(\x04\x12+\n\x07valsets\x18\x03 \x03(\x0b\x32\x1a.injective.peggy.v1.Valset\x12=\n\x0fvalset_confirms\x18\x04 \x03(\x0b\x32$.injective.peggy.v1.MsgValsetConfirm\x12\x34\n\x07\x62\x61tches\x18\x05 \x03(\x0b\x32#.injective.peggy.v1.OutgoingTxBatch\x12;\n\x0e\x62\x61tch_confirms\x18\x06 \x03(\x0b\x32#.injective.peggy.v1.MsgConfirmBatch\x12\x35\n\x0c\x61ttestations\x18\x07 \x03(\x0b\x32\x1f.injective.peggy.v1.Attestation\x12O\n\x16orchestrator_addresses\x18\x08 \x03(\x0b\x32/.injective.peggy.v1.MsgSetOrchestratorAddresses\x12\x39\n\x0f\x65rc20_to_denoms\x18\t \x03(\x0b\x32 .injective.peggy.v1.ERC20ToDenom\x12\x43\n\x13unbatched_transfers\x18\n \x03(\x0b\x32&.injective.peggy.v1.OutgoingTransferTx\x12%\n\x1dlast_observed_ethereum_height\x18\x0b \x01(\x04\x12\x1e\n\x16last_outgoing_batch_id\x18\x0c \x01(\x04\x12\x1d\n\x15last_outgoing_pool_id\x18\r \x01(\x04\x12>\n\x14last_observed_valset\x18\x0e \x01(\x0b\x32\x1a.injective.peggy.v1.ValsetB\x04\xc8\xde\x1f\x00\x12\x1a\n\x12\x65thereum_blacklist\x18\x0f \x03(\tBMZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.peggy.v1.genesis_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types'
  _GENESISSTATE.fields_by_name['last_observed_valset']._options = None
  _GENESISSTATE.fields_by_name['last_observed_valset']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=277
  _globals['_GENESISSTATE']._serialized_end=1045
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/fee/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from ibc.applications.fee.v1 import fee_pb2 as ibc_dot_applications_dot_fee_dot_v1_dot_fee__pb2
from ibc.applications.fee.v1 import genesis_pb2 as ibc_dot_applications_dot_fee_dot_v1_dot_genesis__pb2
from ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#ibc/applications/fee/v1/query.proto\x12\x17ibc.applications.fee.v1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a!ibc/applications/fee/v1/fee.proto\x1a%ibc/applications/fee/v1/genesis.proto\x1a!ibc/core/channel/v1/channel.proto\"s\n\x1fQueryIncentivizedPacketsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\x12\x14\n\x0cquery_height\x18\x02 \x01(\x04\"u\n QueryIncentivizedPacketsResponse\x12Q\n\x14incentivized_packets\x18\x01 \x03(\x0b\x32-.ibc.applications.fee.v1.IdentifiedPacketFeesB\x04\xc8\xde\x1f\x00\"n\n\x1eQueryIncentivizedPacketRequest\x12\x36\n\tpacket_id\x18\x01 \x01(\x0b\x32\x1d.ibc.core.channel.v1.PacketIdB\x04\xc8\xde\x1f\x00\x12\x14\n\x0cquery_height\x18\x02 \x01(\x04\"s\n\x1fQueryIncentivizedPacketResponse\x12P\n\x13incentivized_packet\x18\x01 \x01(\x0b\x32-.ibc.applications.fee.v1.IdentifiedPacketFeesB\x04\xc8\xde\x1f\x00\"\xa2\x01\n)QueryIncentivizedPacketsForChannelRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\x12\x0f\n\x07port_id\x18\x02 \x01(\t\x12\x12\n\nchannel_id\x18\x03 \x01(\t\x12\x14\n\x0cquery_height\x18\x04 \x01(\x04\"y\n*QueryIncentivizedPacketsForChannelResponse\x12K\n\x14incentivized_packets\x18\x01 \x03(\x0b\x32-.ibc.applications.fee.v1.IdentifiedPacketFees\"S\n\x19QueryTotalRecvFeesRequest\x12\x36\n\tpacket_id\x18\x01 \x01(\x0b\x32\x1d.ibc.core.channel.v1.PacketIdB\x04\xc8\xde\x1f\x00\"\x90\x01\n\x1aQueryTotalRecvFeesResponse\x12r\n\trecv_fees\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBD\xc8\xde\x1f\x00\xf2\xde\x1f\x10yaml:\"recv_fees\"\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"R\n\x18QueryTotalAckFeesRequest\x12\x36\n\tpacket_id\x18\x01 \x01(\x0b\x32\x1d.ibc.core.channel.v1.PacketIdB\x04\xc8\xde\x1f\x00\"\x8d\x01\n\x19QueryTotalAckFeesResponse\x12p\n\x08\x61\x63k_fees\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBC\xc8\xde\x1f\x00\xf2\xde\x1f\x0fyaml:\"ack_fees\"\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"V\n\x1cQueryTotalTimeoutFeesRequest\x12\x36\n\tpacket_id\x18\x01 \x01(\x0b\x32\x1d.ibc.core.channel.v1.PacketIdB\x04\xc8\xde\x1f\x00\"\x99\x01\n\x1dQueryTotalTimeoutFeesResponse\x12x\n\x0ctimeout_fees\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBG\xc8\xde\x1f\x00\xf2\xde\x1f\x13yaml:\"timeout_fees\"\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"O\n\x11QueryPayeeRequest\x12)\n\nchannel_id\x18\x01 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"channel_id\"\x12\x0f\n\x07relayer\x18\x02 \x01(\t\"E\n\x12QueryPayeeResponse\x12/\n\rpayee_address\x18\x01 \x01(\tB\x18\xf2\xde\x1f\x14yaml:\"payee_address\"\"[\n\x1dQueryCounterpartyPayeeRequest\x12)\n\nchannel_id\x18\x01 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"channel_id\"\x12\x0f\n\x07relayer\x18\x02 \x01(\t\"[\n\x1eQueryCounterpartyPayeeResponse\x12\x39\n\x12\x63ounterparty_payee\x18\x01 \x01(\tB\x1d\xf2\xde\x1f\x19yaml:\"counterparty_payee\"\"r\n\x1eQueryFeeEnabledChannelsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\x12\x14\n\x0cquery_height\x18\x02 \x01(\x04\"\x90\x01\n\x1fQueryFeeEnabledChannelsResponse\x12m\n\x14\x66\x65\x65_enabled_channels\x18\x01 \x03(\x0b\x32*.ibc.applications.fee.v1.FeeEnabledChannelB#\xc8\xde\x1f\x00\xf2\xde\x1f\x1byaml:\"fee_enabled_channels\"\"o\n\x1dQueryFeeEnabledChannelRequest\x12#\n\x07port_id\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:\"port_id\"\x12)\n\nchannel_id\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"channel_id\"\"M\n\x1eQueryFeeEnabledChannelResponse\x12+\n\x0b\x66\x65\x65_enabled\x18\x01 \x01(\x08\x42\x16\xf2\xde\x1f\x12yaml:\"fee_enabled\"2\xe6\x11\n\x05Query\x12\xb9\x01\n\x13IncentivizedPackets\x12\x38.ibc.applications.fee.v1.QueryIncentivizedPacketsRequest\x1a\x39.ibc.applications.fee.v1.QueryIncentivizedPacketsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/ibc/apps/fee/v1/incentivized_packets\x12\x8f\x02\n\x12IncentivizedPacket\x12\x37.ibc.applications.fee.v1.QueryIncentivizedPacketRequest\x1a\x38.ibc.applications.fee.v1.QueryIncentivizedPacketResponse\"\x85\x01\x82\xd3\xe4\x93\x02\x7f\x12}/ibc/apps/fee/v1/channels/{packet_id.channel_id}/ports/{packet_id.port_id}/sequences/{packet_id.sequence}/incentivized_packet\x12\xfd\x01\n\x1dIncentivizedPacketsForChannel\x12\x42.ibc.applications.fee.v1.QueryIncentivizedPacketsForChannelRequest\x1a\x43.ibc.applications.fee.v1.QueryIncentivizedPacketsForChannelResponse\"S\x82\xd3\xe4\x93\x02M\x12K/ibc/apps/fee/v1/channels/{channel_id}/ports/{port_id}/incentivized_packets\x12\xfc\x01\n\rTotalRecvFees\x12\x32.ibc.applications.fee.v1.QueryTotalRecvFeesRequest\x1a\x33.ibc.applications.fee.v1.QueryTotalRecvFeesResponse\"\x81\x01\x82\xd3\xe4\x93\x02{\x12y/ibc/apps/fee/v1/channels/{packet_id.channel_id}/ports/{packet_id.port_id}/sequences/{packet_id.sequence}/total_recv_fees\x12\xf8\x01\n\x0cTotalAckFees\x12\x31.ibc.applications.fee.v1.QueryTotalAckFeesRequest\x1a\x32.ibc.applications.fee.v1.QueryTotalAckFeesResponse\"\x80\x01\x82\xd3\xe4\x93\x02z\x12x/ibc/apps/fee/v1/channels/{packet_id.channel_id}/ports/{packet_id.port_id}/sequences/{packet_id.sequence}/total_ack_fees\x12\x88\x02\n\x10TotalTimeoutFees\x12\x35.ibc.applications.fee.v1.QueryTotalTimeoutFeesRequest\x1a\x36.ibc.applications.fee.v1.QueryTotalTimeoutFeesResponse\"\x84\x01\x82\xd3\xe4\x93\x02~\x12|/ibc/apps/fee/v1/channels/{packet_id.channel_id}/ports/{packet_id.port_id}/sequences/{packet_id.sequence}/total_timeout_fees\x12\xa9\x01\n\x05Payee\x12*.ibc.applications.fee.v1.QueryPayeeRequest\x1a+.ibc.applications.fee.v1.QueryPayeeResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/ibc/apps/fee/v1/channels/{channel_id}/relayers/{relayer}/payee\x12\xda\x01\n\x11\x43ounterpartyPayee\x12\x36.ibc.applications.fee.v1.QueryCounterpartyPayeeRequest\x1a\x37.ibc.applications.fee.v1.QueryCounterpartyPayeeResponse\"T\x82\xd3\xe4\x93\x02N\x12L/ibc/apps/fee/v1/channels/{channel_id}/relayers/{relayer}/counterparty_payee\x12\xad\x01\n\x12\x46\x65\x65\x45nabledChannels\x12\x37.ibc.applications.fee.v1.QueryFeeEnabledChannelsRequest\x1a\x38.ibc.applications.fee.v1.QueryFeeEnabledChannelsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/ibc/apps/fee/v1/fee_enabled\x12\xd0\x01\n\x11\x46\x65\x65\x45nabledChannel\x12\x36.ibc.applications.fee.v1.QueryFeeEnabledChannelRequest\x1a\x37.ibc.applications.fee.v1.QueryFeeEnabledChannelResponse\"J\x82\xd3\xe4\x93\x02\x44\x12\x42/ibc/apps/fee/v1/channels/{channel_id}/ports/{port_id}/fee_enabledB7Z5github.com/cosmos/ibc-go/v7/modules/apps/29-fee/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.fee.v1.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/cosmos/ibc-go/v7/modules/apps/29-fee/types'
  _QUERYINCENTIVIZEDPACKETSRESPONSE.fields_by_name['incentivized_packets']._options = None
  _QUERYINCENTIVIZEDPACKETSRESPONSE.fields_by_name['incentivized_packets']._serialized_options = b'\310\336\037\000'
  _QUERYINCENTIVIZEDPACKETREQUEST.fields_by_name['packet_id']._options = None
  _QUERYINCENTIVIZEDPACKETREQUEST.fields_by_name['packet_id']._serialized_options = b'\310\336\037\000'
  _QUERYINCENTIVIZEDPACKETRESPONSE.fields_by_name['incentivized_packet']._options = None
  _QUERYINCENTIVIZEDPACKETRESPONSE.fields_by_name['incentivized_packet']._serialized_options = b'\310\336\037\000'
  _QUERYTOTALRECVFEESREQUEST.fields_by_name['packet_id']._options = None
  _QUERYTOTALRECVFEESREQUEST.fields_by_name['packet_id']._serialized_options = b'\310\336\037\000'
  _QUERYTOTALRECVFEESRESPONSE.fields_by_name['recv_fees']._options = None
  _QUERYTOTALRECVFEESRESPONSE.fields_by_name['recv_fees']._serialized_options = b'\310\336\037\000\362\336\037\020yaml:\"recv_fees\"\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _QUERYTOTALACKFEESREQUEST.fields_by_name['packet_id']._options = None
  _QUERYTOTALACKFEESREQUEST.fields_by_name['packet_id']._serialized_options = b'\310\336\037\000'
  _QUERYTOTALACKFEESRESPONSE.fields_by_name['ack_fees']._options = None
  _QUERYTOTALACKFEESRESPONSE.fields_by_name['ack_fees']._serialized_options = b'\310\336\037\000\362\336\037\017yaml:\"ack_fees\"\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _QUERYTOTALTIMEOUTFEESREQUEST.fields_by_name['packet_id']._options = None
  _QUERYTOTALTIMEOUTFEESREQUEST.fields_by_name['packet_id']._serialized_options = b'\310\336\037\000'
  _QUERYTOTALTIMEOUTFEESRESPONSE.fields_by_name['timeout_fees']._options = None
  _QUERYTOTALTIMEOUTFEESRESPONSE.fields_by_name['timeout_fees']._serialized_options = b'\310\336\037\000\362\336\037\023yaml:\"timeout_fees\"\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _QUERYPAYEEREQUEST.fields_by_name['channel_id']._options = None
  _QUERYPAYEEREQUEST.fields_by_name['channel_id']._serialized_options = b'\362\336\037\021yaml:\"channel_id\"'
  _QUERYPAYEERESPONSE.fields_by_name['payee_address']._options = None
  _QUERYPAYEERESPONSE.fields_by_name['payee_address']._serialized_options = b'\362\336\037\024yaml:\"payee_address\"'
  _QUERYCOUNTERPARTYPAYEEREQUEST.fields_by_name['channel_id']._options = None
  _QUERYCOUNTERPARTYPAYEEREQUEST.fields_by_name['channel_id']._serialized_options = b'\362\336\037\021yaml:\"channel_id\"'
  _QUERYCOUNTERPARTYPAYEERESPONSE.fields_by_name['counterparty_payee']._options = None
  _QUERYCOUNTERPARTYPAYEERESPONSE.fields_by_name['counterparty_payee']._serialized_options = b'\362\336\037\031yaml:\"counterparty_payee\"'
  _QUERYFEEENABLEDCHANNELSRESPONSE.fields_by_name['fee_enabled_channels']._options = None
  _QUERYFEEENABLEDCHANNELSRESPONSE.fields_by_name['fee_enabled_channels']._serialized_options = b'\310\336\037\000\362\336\037\033yaml:\"fee_enabled_channels\"'
  _QUERYFEEENABLEDCHANNELREQUEST.fields_by_name['port_id']._options = None
  _QUERYFEEENABLEDCHANNELREQUEST.fields_by_name['port_id']._serialized_options = b'\362\336\037\016yaml:\"port_id\"'
  _QUERYFEEENABLEDCHANNELREQUEST.fields_by_name['channel_id']._options = None
  _QUERYFEEENABLEDCHANNELREQUEST.fields_by_name['channel_id']._serialized_options = b'\362\336\037\021yaml:\"channel_id\"'
  _QUERYFEEENABLEDCHANNELRESPONSE.fields_by_name['fee_enabled']._options = None
  _QUERYFEEENABLEDCHANNELRESPONSE.fields_by_name['fee_enabled']._serialized_options = b'\362\336\037\022yaml:\"fee_enabled\"'
  _QUERY.methods_by_name['IncentivizedPackets']._options = None
  _QUERY.methods_by_name['IncentivizedPackets']._serialized_options = b'\202\323\344\223\002\'\022%/ibc/apps/fee/v1/incentivized_packets'
  _QUERY.methods_by_name['IncentivizedPacket']._options = None
  _QUERY.methods_by_name['IncentivizedPacket']._serialized_options = b'\202\323\344\223\002\177\022}/ibc/apps/fee/v1/channels/{packet_id.channel_id}/ports/{packet_id.port_id}/sequences/{packet_id.sequence}/incentivized_packet'
  _QUERY.methods_by_name['IncentivizedPacketsForChannel']._options = None
  _QUERY.methods_by_name['IncentivizedPacketsForChannel']._serialized_options = b'\202\323\344\223\002M\022K/ibc/apps/fee/v1/channels/{channel_id}/ports/{port_id}/incentivized_packets'
  _QUERY.methods_by_name['TotalRecvFees']._options = None
  _QUERY.methods_by_name['TotalRecvFees']._serialized_options = b'\202\323\344\223\002{\022y/ibc/apps/fee/v1/channels/{packet_id.channel_id}/ports/{packet_id.port_id}/sequences/{packet_id.sequence}/total_recv_fees'
  _QUERY.methods_by_name['TotalAckFees']._options = None
  _QUERY.methods_by_name['TotalAckFees']._serialized_options = b'\202\323\344\223\002z\022x/ibc/apps/fee/v1/channels/{packet_id.channel_id}/ports/{packet_id.port_id}/sequences/{packet_id.sequence}/total_ack_fees'
  _QUERY.methods_by_name['TotalTimeoutFees']._options = None
  _QUERY.methods_by_name['TotalTimeoutFees']._serialized_options = b'\202\323\344\223\002~\022|/ibc/apps/fee/v1/channels/{packet_id.channel_id}/ports/{packet_id.port_id}/sequences/{packet_id.sequence}/total_timeout_fees'
  _QUERY.methods_by_name['Payee']._options = None
  _QUERY.methods_by_name['Payee']._serialized_options = b'\202\323\344\223\002A\022?/ibc/apps/fee/v1/channels/{channel_id}/relayers/{relayer}/payee'
  _QUERY.methods_by_name['CounterpartyPayee']._options = None
  _QUERY.methods_by_name['CounterpartyPayee']._serialized_options = b'\202\323\344\223\002N\022L/ibc/apps/fee/v1/channels/{channel_id}/relayers/{relayer}/counterparty_payee'
  _QUERY.methods_by_name['FeeEnabledChannels']._options = None
  _QUERY.methods_by_name['FeeEnabledChannels']._serialized_options = b'\202\323\344\223\002\036\022\034/ibc/apps/fee/v1/fee_enabled'
  _QUERY.methods_by_name['FeeEnabledChannel']._options = None
  _QUERY.methods_by_name['FeeEnabledChannel']._serialized_options = b'\202\323\344\223\002D\022B/ibc/apps/fee/v1/channels/{channel_id}/ports/{port_id}/fee_enabled'
  _globals['_QUERYINCENTIVIZEDPACKETSREQUEST']._serialized_start=301
  _globals['_QUERYINCENTIVIZEDPACKETSREQUEST']._serialized_end=416
  _globals['_QUERYINCENTIVIZEDPACKETSRESPONSE']._serialized_start=418
  _globals['_QUERYINCENTIVIZEDPACKETSRESPONSE']._serialized_end=535
  _globals['_QUERYINCENTIVIZEDPACKETREQUEST']._serialized_start=537
  _globals['_QUERYINCENTIVIZEDPACKETREQUEST']._serialized_end=647
  _globals['_QUERYINCENTIVIZEDPACKETRESPONSE']._serialized_start=649
  _globals['_QUERYINCENTIVIZEDPACKETRESPONSE']._serialized_end=764
  _globals['_QUERYINCENTIVIZEDPACKETSFORCHANNELREQUEST']._serialized_start=767
  _globals['_QUERYINCENTIVIZEDPACKETSFORCHANNELREQUEST']._serialized_end=929
  _globals['_QUERYINCENTIVIZEDPACKETSFORCHANNELRESPONSE']._serialized_start=931
  _globals['_QUERYINCENTIVIZEDPACKETSFORCHANNELRESPONSE']._serialized_end=1052
  _globals['_QUERYTOTALRECVFEESREQUEST']._serialized_start=1054
  _globals['_QUERYTOTALRECVFEESREQUEST']._serialized_end=1137
  _globals['_QUERYTOTALRECVFEESRESPONSE']._serialized_start=1140
  _globals['_QUERYTOTALRECVFEESRESPONSE']._serialized_end=1284
  _globals['_QUERYTOTALACKFEESREQUEST']._serialized_start=1286
  _globals['_QUERYTOTALACKFEESREQUEST']._serialized_end=1368
  _globals['_QUERYTOTALACKFEESRESPONSE']._serialized_start=1371
  _globals['_QUERYTOTALACKFEESRESPONSE']._serialized_end=1512
  _globals['_QUERYTOTALTIMEOUTFEESREQUEST']._serialized_start=1514
  _globals['_QUERYTOTALTIMEOUTFEESREQUEST']._serialized_end=1600
  _globals['_QUERYTOTALTIMEOUTFEESRESPONSE']._serialized_start=1603
  _globals['_QUERYTOTALTIMEOUTFEESRESPONSE']._serialized_end=1756
  _globals['_QUERYPAYEEREQUEST']._serialized_start=1758
  _globals['_QUERYPAYEEREQUEST']._serialized_end=1837
  _globals['_QUERYPAYEERESPONSE']._serialized_start=1839
  _globals['_QUERYPAYEERESPONSE']._serialized_end=1908
  _globals['_QUERYCOUNTERPARTYPAYEEREQUEST']._serialized_start=1910
  _globals['_QUERYCOUNTERPARTYPAYEEREQUEST']._serialized_end=2001
  _globals['_QUERYCOUNTERPARTYPAYEERESPONSE']._serialized_start=2003
  _globals['_QUERYCOUNTERPARTYPAYEERESPONSE']._serialized_end=2094
  _globals['_QUERYFEEENABLEDCHANNELSREQUEST']._serialized_start=2096
  _globals['_QUERYFEEENABLEDCHANNELSREQUEST']._serialized_end=2210
  _globals['_QUERYFEEENABLEDCHANNELSRESPONSE']._serialized_start=2213
  _globals['_QUERYFEEENABLEDCHANNELSRESPONSE']._serialized_end=2357
  _globals['_QUERYFEEENABLEDCHANNELREQUEST']._serialized_start=2359
  _globals['_QUERYFEEENABLEDCHANNELREQUEST']._serialized_end=2470
  _globals['_QUERYFEEENABLEDCHANNELRESPONSE']._serialized_start=2472
  _globals['_QUERYFEEENABLEDCHANNELRESPONSE']._serialized_end=2549
  _globals['_QUERY']._serialized_start=2552
  _globals['_QUERY']._serialized_end=4830
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/capability/v1beta1/capability.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*cosmos/capability/v1beta1/capability.proto\x12\x19\x63osmos.capability.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x11\x61mino/amino.proto\"!\n\nCapability\x12\r\n\x05index\x18\x01 \x01(\x04:\x04\x98\xa0\x1f\x00\"/\n\x05Owner\x12\x0e\n\x06module\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t:\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x00\"O\n\x10\x43\x61pabilityOwners\x12;\n\x06owners\x18\x01 \x03(\x0b\x32 .cosmos.capability.v1beta1.OwnerB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x42\x31Z/github.com/cosmos/cosmos-sdk/x/capability/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.capability.v1beta1.capability_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/cosmos/cosmos-sdk/x/capability/types'
  _CAPABILITY._options = None
  _CAPABILITY._serialized_options = b'\230\240\037\000'
  _OWNER._options = None
  _OWNER._serialized_options = b'\210\240\037\000\230\240\037\000'
  _CAPABILITYOWNERS.fields_by_name['owners']._options = None
  _CAPABILITYOWNERS.fields_by_name['owners']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_CAPABILITY']._serialized_start=114
  _globals['_CAPABILITY']._serialized_end=147
  _globals['_OWNER']._serialized_start=149
  _globals['_OWNER']._serialized_end=196
  _globals['_CAPABILITYOWNERS']._serialized_start=198
  _globals['_CAPABILITYOWNERS']._serialized_end=277
# @@protoc_insertion_point(module_scope)



from web3 import Web3

from .utils.logger import LoggerProvider
from .wallet import Address


class Peggo:
    def __init__(self, network: str):
        self.network = network

    def sendToInjective(
        self,
        ethereum_endpoint: str,
        private_key: str,
        token_contract: str,
        receiver: str,
        amount: float,
        maxFeePerGas: int,
        maxPriorityFeePerGas: int,
        peggo_abi: str,
        data: str,
        decimals=18,
    ):
        if self.network == "testnet":
            peggy_proxy_address = "0xd2C6753F6B1783EF0a3857275e16e79D91b539a3"
        elif self.network == "mainnet":
            peggy_proxy_address = "0xF955C57f9EA9Dc8781965FEaE0b6A2acE2BAD6f3"
        elif self.network == "devnet":
            peggy_proxy_address = "0x4F38F75606d046819638f909b66B112aF1095e8d"
        else:
            LoggerProvider().logger_for_class(logging_class=self.__class__).info("Network is not supported")
            raise RuntimeError(f"Network {self.network} not supported")
        web3 = Web3(Web3.HTTPProvider(ethereum_endpoint))
        contract = web3.eth.contract(address=peggy_proxy_address, abi=peggo_abi)

        token_contract_address = web3.to_checksum_address(token_contract)

        receiver_address = Address.from_acc_bech32(receiver)
        receiver_ethereum_address = Address.get_ethereum_address(receiver_address)
        receiver_address_checksum = web3.to_checksum_address(receiver_ethereum_address)
        receiver_slice = receiver_address_checksum[2:]
        receiver_padded_address = "0x" + receiver_slice.zfill(64)

        destination = web3.to_bytes(hexstr=receiver_padded_address)

        sender_ethereum_address = web3.eth.account.from_key(private_key).address
        sender_address_checksum = web3.to_checksum_address(sender_ethereum_address)
        nonce = web3.eth.get_transaction_count(sender_address_checksum)

        amount_to_send = int(amount * pow(10, decimals))

        gas = contract.functions.sendToInjective(
            token_contract_address, destination, amount_to_send, data
        ).estimate_gas({"from": sender_address_checksum})

        transaction_body = {
            "nonce": nonce,
            "gas": gas,
            "maxFeePerGas": web3.to_wei(maxFeePerGas, "gwei"),
            "maxPriorityFeePerGas": web3.to_wei(maxPriorityFeePerGas, "gwei"),
        }

        tx = contract.functions.sendToInjective(
            token_contract_address, destination, amount_to_send, data
        ).buildTransaction(transaction_body)

        signed_tx = web3.eth.account.signTransaction(tx, private_key=private_key)

        try:
            tx_hash = web3.eth.send_raw_transaction(signed_tx.rawTransaction)
            LoggerProvider().logger_for_class(logging_class=self.__class__).info(
                f"Transferred {amount} {token_contract} from {sender_ethereum_address} to {receiver}"
            )
            LoggerProvider().logger_for_class(logging_class=self.__class__).info(
                "Transaction hash: {}".format(Web3.to_hex(tx_hash))
            )
        except Exception as e:
            LoggerProvider().logger_for_class(logging_class=self.__class__).info("Transaction failed {}".format(e))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/connection/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from ibc.core.connection.v1 import connection_pb2 as ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fibc/core/connection/v1/tx.proto\x12\x16ibc.core.connection.v1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x1fibc/core/client/v1/client.proto\x1a\'ibc/core/connection/v1/connection.proto\"\xfd\x01\n\x15MsgConnectionOpenInit\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"client_id\"\x12@\n\x0c\x63ounterparty\x18\x02 \x01(\x0b\x32$.ibc.core.connection.v1.CounterpartyB\x04\xc8\xde\x1f\x00\x12\x30\n\x07version\x18\x03 \x01(\x0b\x32\x1f.ibc.core.connection.v1.Version\x12-\n\x0c\x64\x65lay_period\x18\x04 \x01(\x04\x42\x17\xf2\xde\x1f\x13yaml:\"delay_period\"\x12\x0e\n\x06signer\x18\x05 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x1f\n\x1dMsgConnectionOpenInitResponse\"\x8f\x06\n\x14MsgConnectionOpenTry\x12\'\n\tclient_id\x18\x01 \x01(\tB\x14\xf2\xde\x1f\x10yaml:\"client_id\"\x12\x43\n\x16previous_connection_id\x18\x02 \x01(\tB#\x18\x01\xf2\xde\x1f\x1dyaml:\"previous_connection_id\"\x12\x43\n\x0c\x63lient_state\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB\x17\xf2\xde\x1f\x13yaml:\"client_state\"\x12@\n\x0c\x63ounterparty\x18\x04 \x01(\x0b\x32$.ibc.core.connection.v1.CounterpartyB\x04\xc8\xde\x1f\x00\x12-\n\x0c\x64\x65lay_period\x18\x05 \x01(\x04\x42\x17\xf2\xde\x1f\x13yaml:\"delay_period\"\x12`\n\x15\x63ounterparty_versions\x18\x06 \x03(\x0b\x32\x1f.ibc.core.connection.v1.VersionB \xf2\xde\x1f\x1cyaml:\"counterparty_versions\"\x12M\n\x0cproof_height\x18\x07 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1b\xc8\xde\x1f\x00\xf2\xde\x1f\x13yaml:\"proof_height\"\x12)\n\nproof_init\x18\x08 \x01(\x0c\x42\x15\xf2\xde\x1f\x11yaml:\"proof_init\"\x12-\n\x0cproof_client\x18\t \x01(\x0c\x42\x17\xf2\xde\x1f\x13yaml:\"proof_client\"\x12\x33\n\x0fproof_consensus\x18\n \x01(\x0c\x42\x1a\xf2\xde\x1f\x16yaml:\"proof_consensus\"\x12U\n\x10\x63onsensus_height\x18\x0b \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1f\xc8\xde\x1f\x00\xf2\xde\x1f\x17yaml:\"consensus_height\"\x12\x0e\n\x06signer\x18\x0c \x01(\t\x12\"\n\x1ahost_consensus_state_proof\x18\r \x01(\x0c:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x1e\n\x1cMsgConnectionOpenTryResponse\"\xfa\x04\n\x14MsgConnectionOpenAck\x12/\n\rconnection_id\x18\x01 \x01(\tB\x18\xf2\xde\x1f\x14yaml:\"connection_id\"\x12I\n\x1a\x63ounterparty_connection_id\x18\x02 \x01(\tB%\xf2\xde\x1f!yaml:\"counterparty_connection_id\"\x12\x30\n\x07version\x18\x03 \x01(\x0b\x32\x1f.ibc.core.connection.v1.Version\x12\x43\n\x0c\x63lient_state\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyB\x17\xf2\xde\x1f\x13yaml:\"client_state\"\x12M\n\x0cproof_height\x18\x05 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1b\xc8\xde\x1f\x00\xf2\xde\x1f\x13yaml:\"proof_height\"\x12\'\n\tproof_try\x18\x06 \x01(\x0c\x42\x14\xf2\xde\x1f\x10yaml:\"proof_try\"\x12-\n\x0cproof_client\x18\x07 \x01(\x0c\x42\x17\xf2\xde\x1f\x13yaml:\"proof_client\"\x12\x33\n\x0fproof_consensus\x18\x08 \x01(\x0c\x42\x1a\xf2\xde\x1f\x16yaml:\"proof_consensus\"\x12U\n\x10\x63onsensus_height\x18\t \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1f\xc8\xde\x1f\x00\xf2\xde\x1f\x17yaml:\"consensus_height\"\x12\x0e\n\x06signer\x18\n \x01(\t\x12\"\n\x1ahost_consensus_state_proof\x18\x0b \x01(\x0c:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x1e\n\x1cMsgConnectionOpenAckResponse\"\xdd\x01\n\x18MsgConnectionOpenConfirm\x12/\n\rconnection_id\x18\x01 \x01(\tB\x18\xf2\xde\x1f\x14yaml:\"connection_id\"\x12\'\n\tproof_ack\x18\x02 \x01(\x0c\x42\x14\xf2\xde\x1f\x10yaml:\"proof_ack\"\x12M\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x1b\xc8\xde\x1f\x00\xf2\xde\x1f\x13yaml:\"proof_height\"\x12\x0e\n\x06signer\x18\x04 \x01(\t:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\"\n MsgConnectionOpenConfirmResponse2\xf9\x03\n\x03Msg\x12z\n\x12\x43onnectionOpenInit\x12-.ibc.core.connection.v1.MsgConnectionOpenInit\x1a\x35.ibc.core.connection.v1.MsgConnectionOpenInitResponse\x12w\n\x11\x43onnectionOpenTry\x12,.ibc.core.connection.v1.MsgConnectionOpenTry\x1a\x34.ibc.core.connection.v1.MsgConnectionOpenTryResponse\x12w\n\x11\x43onnectionOpenAck\x12,.ibc.core.connection.v1.MsgConnectionOpenAck\x1a\x34.ibc.core.connection.v1.MsgConnectionOpenAckResponse\x12\x83\x01\n\x15\x43onnectionOpenConfirm\x12\x30.ibc.core.connection.v1.MsgConnectionOpenConfirm\x1a\x38.ibc.core.connection.v1.MsgConnectionOpenConfirmResponseB>Z<github.com/cosmos/ibc-go/v7/modules/core/03-connection/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.connection.v1.tx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z<github.com/cosmos/ibc-go/v7/modules/core/03-connection/types'
  _MSGCONNECTIONOPENINIT.fields_by_name['client_id']._options = None
  _MSGCONNECTIONOPENINIT.fields_by_name['client_id']._serialized_options = b'\362\336\037\020yaml:\"client_id\"'
  _MSGCONNECTIONOPENINIT.fields_by_name['counterparty']._options = None
  _MSGCONNECTIONOPENINIT.fields_by_name['counterparty']._serialized_options = b'\310\336\037\000'
  _MSGCONNECTIONOPENINIT.fields_by_name['delay_period']._options = None
  _MSGCONNECTIONOPENINIT.fields_by_name['delay_period']._serialized_options = b'\362\336\037\023yaml:\"delay_period\"'
  _MSGCONNECTIONOPENINIT._options = None
  _MSGCONNECTIONOPENINIT._serialized_options = b'\210\240\037\000\350\240\037\000'
  _MSGCONNECTIONOPENTRY.fields_by_name['client_id']._options = None
  _MSGCONNECTIONOPENTRY.fields_by_name['client_id']._serialized_options = b'\362\336\037\020yaml:\"client_id\"'
  _MSGCONNECTIONOPENTRY.fields_by_name['previous_connection_id']._options = None
  _MSGCONNECTIONOPENTRY.fields_by_name['previous_connection_id']._serialized_options = b'\030\001\362\336\037\035yaml:\"previous_connection_id\"'
  _MSGCONNECTIONOPENTRY.fields_by_name['client_state']._options = None
  _MSGCONNECTIONOPENTRY.fields_by_name['client_state']._serialized_options = b'\362\336\037\023yaml:\"client_state\"'
  _MSGCONNECTIONOPENTRY.fields_by_name['counterparty']._options = None
  _MSGCONNECTIONOPENTRY.fields_by_name['counterparty']._serialized_options = b'\310\336\037\000'
  _MSGCONNECTIONOPENTRY.fields_by_name['delay_period']._options = None
  _MSGCONNECTIONOPENTRY.fields_by_name['delay_period']._serialized_options = b'\362\336\037\023yaml:\"delay_period\"'
  _MSGCONNECTIONOPENTRY.fields_by_name['counterparty_versions']._options = None
  _MSGCONNECTIONOPENTRY.fields_by_name['counterparty_versions']._serialized_options = b'\362\336\037\034yaml:\"counterparty_versions\"'
  _MSGCONNECTIONOPENTRY.fields_by_name['proof_height']._options = None
  _MSGCONNECTIONOPENTRY.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000\362\336\037\023yaml:\"proof_height\"'
  _MSGCONNECTIONOPENTRY.fields_by_name['proof_init']._options = None
  _MSGCONNECTIONOPENTRY.fields_by_name['proof_init']._serialized_options = b'\362\336\037\021yaml:\"proof_init\"'
  _MSGCONNECTIONOPENTRY.fields_by_name['proof_client']._options = None
  _MSGCONNECTIONOPENTRY.fields_by_name['proof_client']._serialized_options = b'\362\336\037\023yaml:\"proof_client\"'
  _MSGCONNECTIONOPENTRY.fields_by_name['proof_consensus']._options = None
  _MSGCONNECTIONOPENTRY.fields_by_name['proof_consensus']._serialized_options = b'\362\336\037\026yaml:\"proof_consensus\"'
  _MSGCONNECTIONOPENTRY.fields_by_name['consensus_height']._options = None
  _MSGCONNECTIONOPENTRY.fields_by_name['consensus_height']._serialized_options = b'\310\336\037\000\362\336\037\027yaml:\"consensus_height\"'
  _MSGCONNECTIONOPENTRY._options = None
  _MSGCONNECTIONOPENTRY._serialized_options = b'\210\240\037\000\350\240\037\000'
  _MSGCONNECTIONOPENACK.fields_by_name['connection_id']._options = None
  _MSGCONNECTIONOPENACK.fields_by_name['connection_id']._serialized_options = b'\362\336\037\024yaml:\"connection_id\"'
  _MSGCONNECTIONOPENACK.fields_by_name['counterparty_connection_id']._options = None
  _MSGCONNECTIONOPENACK.fields_by_name['counterparty_connection_id']._serialized_options = b'\362\336\037!yaml:\"counterparty_connection_id\"'
  _MSGCONNECTIONOPENACK.fields_by_name['client_state']._options = None
  _MSGCONNECTIONOPENACK.fields_by_name['client_state']._serialized_options = b'\362\336\037\023yaml:\"client_state\"'
  _MSGCONNECTIONOPENACK.fields_by_name['proof_height']._options = None
  _MSGCONNECTIONOPENACK.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000\362\336\037\023yaml:\"proof_height\"'
  _MSGCONNECTIONOPENACK.fields_by_name['proof_try']._options = None
  _MSGCONNECTIONOPENACK.fields_by_name['proof_try']._serialized_options = b'\362\336\037\020yaml:\"proof_try\"'
  _MSGCONNECTIONOPENACK.fields_by_name['proof_client']._options = None
  _MSGCONNECTIONOPENACK.fields_by_name['proof_client']._serialized_options = b'\362\336\037\023yaml:\"proof_client\"'
  _MSGCONNECTIONOPENACK.fields_by_name['proof_consensus']._options = None
  _MSGCONNECTIONOPENACK.fields_by_name['proof_consensus']._serialized_options = b'\362\336\037\026yaml:\"proof_consensus\"'
  _MSGCONNECTIONOPENACK.fields_by_name['consensus_height']._options = None
  _MSGCONNECTIONOPENACK.fields_by_name['consensus_height']._serialized_options = b'\310\336\037\000\362\336\037\027yaml:\"consensus_height\"'
  _MSGCONNECTIONOPENACK._options = None
  _MSGCONNECTIONOPENACK._serialized_options = b'\210\240\037\000\350\240\037\000'
  _MSGCONNECTIONOPENCONFIRM.fields_by_name['connection_id']._options = None
  _MSGCONNECTIONOPENCONFIRM.fields_by_name['connection_id']._serialized_options = b'\362\336\037\024yaml:\"connection_id\"'
  _MSGCONNECTIONOPENCONFIRM.fields_by_name['proof_ack']._options = None
  _MSGCONNECTIONOPENCONFIRM.fields_by_name['proof_ack']._serialized_options = b'\362\336\037\020yaml:\"proof_ack\"'
  _MSGCONNECTIONOPENCONFIRM.fields_by_name['proof_height']._options = None
  _MSGCONNECTIONOPENCONFIRM.fields_by_name['proof_height']._serialized_options = b'\310\336\037\000\362\336\037\023yaml:\"proof_height\"'
  _MSGCONNECTIONOPENCONFIRM._options = None
  _MSGCONNECTIONOPENCONFIRM._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_MSGCONNECTIONOPENINIT']._serialized_start=183
  _globals['_MSGCONNECTIONOPENINIT']._serialized_end=436
  _globals['_MSGCONNECTIONOPENINITRESPONSE']._serialized_start=438
  _globals['_MSGCONNECTIONOPENINITRESPONSE']._serialized_end=469
  _globals['_MSGCONNECTIONOPENTRY']._serialized_start=472
  _globals['_MSGCONNECTIONOPENTRY']._serialized_end=1255
  _globals['_MSGCONNECTIONOPENTRYRESPONSE']._serialized_start=1257
  _globals['_MSGCONNECTIONOPENTRYRESPONSE']._serialized_end=1287
  _globals['_MSGCONNECTIONOPENACK']._serialized_start=1290
  _globals['_MSGCONNECTIONOPENACK']._serialized_end=1924
  _globals['_MSGCONNECTIONOPENACKRESPONSE']._serialized_start=1926
  _globals['_MSGCONNECTIONOPENACKRESPONSE']._serialized_end=1956
  _globals['_MSGCONNECTIONOPENCONFIRM']._serialized_start=1959
  _globals['_MSGCONNECTIONOPENCONFIRM']._serialized_end=2180
  _globals['_MSGCONNECTIONOPENCONFIRMRESPONSE']._serialized_start=2182
  _globals['_MSGCONNECTIONOPENCONFIRMRESPONSE']._serialized_end=2216
  _globals['_MSG']._serialized_start=2219
  _globals['_MSG']._serialized_end=2724
# @@protoc_insertion_point(module_scope)
